@@ -1,6 +1,7 @@
 import threading
 
 import requests
+import time
 
 from .config import HUB_API_ROOT
 from .utils.general import colorstr
@@ -12,6 +13,8 @@ class HUBLogger:
     def __init__(self, model_id, auth):
         self.model_id = model_id
         self.auth = auth
+        self.rate_limit = 60.0  # minimum seconds between uploads
+        self.t = 0.0  # last upload time
 
     def on_model_save(self, *args, **kwargs):
         """
@@ -27,7 +30,9 @@ class HUBLogger:
         last, epoch, final_epoch, best_fitness, fi = args[:5]
         is_best = best_fitness == fi
 
-        threading.Thread(target=self._upload_model, args=(epoch, is_best, last), daemon=True).start()
+        if (time.time() - self.t) > 0:
+            threading.Thread(target=self._upload_model, args=(epoch, is_best, last), daemon=True).start()
+        self.t = time.time()
 
     def _upload_model(self, epoch, is_best, weights):
         api_url = HUB_API_ROOT + "model-checkpoint"
